@@ -244,6 +244,73 @@ class SupplyChainNetwork(object):
 
 		return self._period == other._period and \
 			self.max_max_replenishment_time == other.max_max_replenishment_time
+
+	def to_dict(self):
+		"""Convert the |class_network| object to a dict. Converts the object recursively,
+		calling ``to_dict()`` on each |class_node| in the network.
+
+		Returns
+		-------
+		dict
+			The dict representation of the network.
+		"""
+		# Initialize dict.
+		network_dict = {}
+
+		# Non-object attributes.
+		network_dict['period'] = self.period
+		network_dict['max_max_replenishment_time'] = self.max_max_replenishment_time
+
+		# Nodes.
+		network_dict['nodes'] = []
+		for n in self.nodes:
+			network_dict['nodes'].append(n.to_dict())
+
+		return network_dict
+
+	@classmethod
+	def from_dict(cls, the_dict):
+		"""Return a new |class_network| object with attributes copied from the
+		values in ``the_dict``. 
+
+		Parameters
+		----------
+		the_dict : dict
+			Dict representation of a |class_network|, typically created using ``to_dict()``.
+
+		Returns
+		-------
+		SupplyChainNetwork
+			The object converted from the dict.
+		"""
+		if the_dict is None:
+			network = None
+		else:
+			# Initialize node object.
+			network = SupplyChainNetwork()
+
+		# Non-object attributes.
+		network.period 						= the_dict['period']
+		network.max_max_replenishment_time	= the_dict['max_max_replenishment_time']
+
+		# Nodes.
+		for n_dict in the_dict['nodes']:
+			network.nodes.append(SupplyChainNode.from_dict(n_dict))
+
+		# Convert nodes' successors and predecessors back to node objects. (SupplyChainNode.to_dict()
+		# replaces them with indices.)
+		for n in network.nodes:
+			preds = []
+			succs = []
+			for m in network.nodes:
+				if m.index in n.predecessors():
+					preds.append(m)
+				if m.index in n.successors():
+					succs.append(m)
+			n._predecessors = preds
+			n._successors = succs
+
+		return network
 			
 	# Methods for node handling.
 
@@ -1135,3 +1202,4 @@ def echelon_to_local_base_stock_levels(network, S_echelon):
 	return S_local
 
 
+
